@@ -197,10 +197,6 @@ class XpanderEventListener:
                 last_exc = exc
                 if attempt < self.max_retries:
                     delay = _backoff_delay(attempt)
-                    logger.warning(
-                        f"{method} {url} failed (attempt {attempt}/{self.max_retries}) – "
-                        f"retrying in {delay}s… ({exc})"
-                    )
                     await asyncio.sleep(delay)
                 else:
                     logger.error(
@@ -271,7 +267,6 @@ class XpanderEventListener:
                 async for event in aiosseclient(url=url, headers=self._headers(), raise_for_status=True):
                     yield event
                 # Stream closed gracefully -> reconnect
-                logger.warning("SSE stream closed – reconnecting…")
                 await asyncio.sleep(_backoff_delay(1))
                 attempt = 1
             except Exception as exc:  # noqa: BLE001 broad
@@ -281,10 +276,6 @@ class XpanderEventListener:
                     )
                     sys.exit(1)
                 delay = _backoff_delay(attempt)
-                logger.warning(
-                    f"SSE connection to {url} failed (attempt {attempt}/{self.max_retries}) – "
-                    f"retrying in {delay}s… ({exc})"
-                )
                 attempt += 1
                 await asyncio.sleep(delay)
 
