@@ -1,6 +1,7 @@
 import random
 import string
 import asyncio
+from uuid import uuid4
 
 def generate_tool_call_id() -> str:
     """
@@ -26,4 +27,7 @@ def get_sub_agent_id_from_oas_by_name(agent_name: str, oas: dict) -> str | None:
     )
 
 async def wait(seconds: int):
-    await asyncio.sleep(seconds)
\ No newline at end of file
+    await asyncio.sleep(seconds)
+
+def get_uuid() -> str:
+    return str(uuid4())
\ No newline at end of file
