@@ -13,9 +13,10 @@ from xpander_sdk import (
     LLMProvider,
     SourceNodeType,
     GraphItem,
+    Agent,
     AgentGraphItemType
 )
-from ...generic import get_sub_agent_id_from_oas_by_name, wait
+from ...generic import get_sub_agent_id_from_oas_by_name, wait, get_uuid
 from .base import SDKAdapter
 import chainlit as cl
 from chainlit import make_async
@@ -524,7 +525,22 @@ class ChainlitAdapter(SDKAdapter):
         
         return tool_calls
 
-    async def process_tool_calls(self,run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], is_sequence_agent: bool = False, sequence_agent_graph_items:List[GraphItem] = [], reported_sequence_sub_agent_ids: set = set(), on_node_enter: Optional[Callable] = None, on_node_error: Optional[Callable] = None, check_if_agent_has_dedicated_workers: Optional[Callable] = None, agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
+    def get_custom_graph_items(self, tool_name: str) -> GraphItem:
+        random_uuid = get_uuid()
+        if tool_name == "xpstorage-save":
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Save Item to Storage", type=AgentGraphItemType.TOOL)
+        elif tool_name == "xpstorage-search":
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Search Items in Storage", type=AgentGraphItemType.TOOL)
+        elif tool_name == "xpstorage-get-last-item":
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Retrieve Latest Item from Storage", type=AgentGraphItemType.TOOL)
+        elif tool_name.startswith("xpkb"):
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Search Knowledge Base", type=AgentGraphItemType.TOOL)
+        elif tool_name.startswith("xpcoder"):
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Running Coding Agent", type=AgentGraphItemType.TOOL)
+        return
+
+    
+    async def process_tool_calls(self,run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], is_sequence_agent: bool = False, sequence_agent_graph_items:List[GraphItem] = [], reported_sequence_sub_agent_ids: set = set(), on_node_enter: Optional[Callable] = None, on_node_error: Optional[Callable] = None, check_if_agent_has_dedicated_workers: Optional[Callable] = None, get_agent_emoji: Optional[Callable] = None, agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
         """
         Process tool calls by formatting their payloads and executing them.
 
@@ -588,12 +604,18 @@ class ChainlitAdapter(SDKAdapter):
             # sleep for animation to work
             await wait(seconds=1)
             
+            agent_name = self.agent.name
+            if get_agent_emoji:
+                emoji = get_agent_emoji(agent_id=self.agent.id)
+                if emoji:
+                    agent_name = f"{emoji} {agent_name}"
+                
             seq_sub_item= cl.Step(
                 type="tool",
                 parent_id=run_id,
                 show_input=False,
                 default_open=True,
-                name=self.agent.name,
+                name=agent_name,
                 id=run_id+"_"+self.agent.id
             )
             seq_sub_item.output=None
@@ -613,7 +635,7 @@ class ChainlitAdapter(SDKAdapter):
                 current_step.name = "xpander-ai"
                 current_step.show_input = False
             
-            graph_item = self.agent.graph.find_node_by_item_id(item_id=tool_call.name) or self.agent.graph.find_node_by_name(name=tool_call.name) or get_custom_function_graph_item(tc=tool_call)
+            graph_item = self.agent.graph.find_node_by_item_id(item_id=tool_call.name) or self.agent.graph.find_node_by_name(name=tool_call.name) or get_custom_function_graph_item(tc=tool_call) or self.get_custom_graph_items(tool_name=tool_call.name)
             tool_name = graph_item.name if graph_item else tool_call.name
             
             is_sub_agent_root = False
@@ -631,6 +653,12 @@ class ChainlitAdapter(SDKAdapter):
                     if on_node_enter:
                         await on_node_enter(tool_call=tool_call,graph_item=sub_agent_node)
                     tool_name = sub_agent_node.name
+                    
+                    if get_agent_emoji:
+                        emoji = get_agent_emoji(agent_id=sub_agent_node.item_id)
+                        if emoji:
+                            tool_name = f"{emoji} {tool_name}"
+                    
                     current_step.id = run_id+"_"+sub_agent_node.item_id
                     is_sub_agent_root = True
             else:
@@ -642,7 +670,13 @@ class ChainlitAdapter(SDKAdapter):
             if is_sub_agent:
                 if is_agent_end_tool:
                     current_step.default_open = True
-                    tool_name = f"{self.agent.name} - Final Thoughts"
+                    agent_name = self.agent.name
+                    if get_agent_emoji:
+                        emoji = get_agent_emoji(agent_id=self.agent.id)
+                        if emoji:
+                            agent_name = f"{emoji} {agent_name}"
+                            
+                    tool_name = f"{agent_name} - Final Thoughts"
                     should_send_step = False
                 else:
                     tool_name = graph_item.name if graph_item else tool_name
